cheesecake.ast_pp.SourceWriter

Package cheesecake :: Module ast_pp :: Class SourceWriter |
[hide private]
[frames] | no frames]

## Class SourceWriter
source code

    object --+
             |
            SourceWriter

Instance Methods | [hide private]
| __init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| w(self, s)
| nl(self)
| indent(self)
| dedent(self)
| visitModule(self, node)
| visitStmt(self, node)
| visitFunction(self, node)
| visitAssign(self, node)
| visitAssName(self, node)
| visitCallFunc(self, node)
| visitListComp(self, node)
| visitListCompFor(self, node)
| visitName(self, node)
| visitDiscard(self, node)
| visitPrintnl(self, node)
| visitGetattr(self, node)
| visitImport(self, node)
| visitFrom(self, node)
| visitConst(self, node)
| visitReturn(self, node)
| visitClass(self, node)
| visitAssAttr(self, node)
| visitMul(self, node)
| visitSub(self, node)
| visitAdd(self, node)
| visitMod(self, node)
| visitAugAssign(self, node)
| visitIf(self, node)
| visitCompare(self, node)
| visitFor(self, node)
| visitSlice(self, node)
| visitTuple(self, node)
| visitTryFinally(self, node)
| visitSubscript(self, node)
| visitUnarySub(self, node)
| visitAssTuple(self, node)
| visitRaise(self, node)
| visitDict(self, node)
| __str__(self) str(x)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
_i |
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### w(self, s) | source code

### nl(self) | source code

### indent(self) | source code

### dedent(self) | source code

### visitModule(self, node) | source code

### visitStmt(self, node) | source code

### visitFunction(self, node) | source code

### visitAssign(self, node) | source code

### visitAssName(self, node) | source code

### visitCallFunc(self, node) | source code

### visitListComp(self, node) | source code

### visitListCompFor(self, node) | source code

### visitName(self, node) | source code

### visitDiscard(self, node) | source code

### visitPrintnl(self, node) | source code

### visitGetattr(self, node) | source code

### visitImport(self, node) | source code

### visitFrom(self, node) | source code

### visitConst(self, node) | source code

### visitReturn(self, node) | source code

### visitClass(self, node) | source code

### visitAssAttr(self, node) | source code

### visitMul(self, node) | source code

### visitSub(self, node) | source code

### visitAdd(self, node) | source code

### visitMod(self, node) | source code

### visitAugAssign(self, node) | source code

### visitIf(self, node) | source code

### visitCompare(self, node) | source code

### visitFor(self, node) | source code

### visitSlice(self, node) | source code

### visitTuple(self, node) | source code

### visitTryFinally(self, node) | source code

### visitSubscript(self, node) | source code

### visitUnarySub(self, node) | source code

### visitAssTuple(self, node) | source code

### visitRaise(self, node) | source code

### visitDict(self, node) | source code

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

Class Variable Details | [hide private]

    ### _i Value:
        0